@@ -57,6 +57,7 @@ public final class CqlUtils
     private static final Pattern ESCAPED_WHITESPACE_PATTERN = Pattern.compile("(\\\\r|\\\\n|\\\\r\\n)+");
     private static final Pattern NEWLINE_PATTERN = Pattern.compile("\n");
     private static final Pattern ESCAPED_DOUBLE_BACKSLASH = Pattern.compile("\\\\");
+    private static final Pattern COMPACTION_STRATEGY_PATTERN = Pattern.compile("compaction\\s*=\\s*\\{\\s*'class'\\s*:\\s*'([^']+)'");
 
     private CqlUtils()
     {
@@ -147,7 +148,7 @@ public final class CqlUtils
         {
             String keyspace = matcher.group(1);
             String table = matcher.group(2);
-            createStmts.put(TableIdentifier.of(keyspace, table), extractCleanedTableSchema(cleaned, keyspace, table));
+            createStmts.put(TableIdentifier.of(keyspace, table), extractCleanedTableSchema(cleaned, keyspace, table, false));
         }
         return createStmts;
     }
@@ -179,19 +180,20 @@ public final class CqlUtils
 
     public static String extractTableSchema(@NotNull String schemaStr, @NotNull String keyspace, @NotNull String table)
     {
-        return extractCleanedTableSchema(cleanCql(schemaStr), keyspace, table);
+        return extractCleanedTableSchema(cleanCql(schemaStr), keyspace, table, false);
     }
 
     public static String extractCleanedTableSchema(@NotNull String createStatementToClean,
                                                    @NotNull String keyspace,
-                                                   @NotNull String table)
+                                                   @NotNull String table,
+                                                   boolean withTableProps)
     {
         Pattern pattern = Pattern.compile(String.format("CREATE TABLE (IF NOT EXISTS)? ?\"?%s?\"?\\.{1}\"?%s\"?[^;]*;", keyspace, table));
         Matcher matcher = pattern.matcher(createStatementToClean);
         if (matcher.find())
         {
             String fullSchema = createStatementToClean.substring(matcher.start(0), matcher.end(0));
-            String redactedSchema = removeTableProps(fullSchema);
+            String redactedSchema = withTableProps ? fullSchema : removeTableProps(fullSchema);
             String clustering = extractClustering(fullSchema);
             String separator = " WITH ";
             if (clustering != null)
@@ -268,4 +270,30 @@ public final class CqlUtils
         }
         return indexCount;
     }
+
+    /**
+     * Extracts the compaction strategy used from table schema.
+     *
+     * @param tableSchema table schema
+     * @return the compaction strategy, or null if not found
+     */
+    public static String extractCompactionStrategy(@NotNull String tableSchema)
+    {
+        Matcher matcher = COMPACTION_STRATEGY_PATTERN.matcher(tableSchema);
+        if (matcher.find())
+        {
+            return matcher.group(1);
+        }
+        return null;
+    }
+
+    /**
+     * Time range filter is only supported for TimeWindowCompactionStrategy.
+     *
+     * @return true if the strategy is TimeWindowCompactionStrategy, false otherwise
+     */
+    public static boolean isTimeRangeFilterSupported(String compactionStrategy)
+    {
+        return compactionStrategy == null || compactionStrategy.endsWith("TimeWindowCompactionStrategy");
+    }
 }
