@@ -52,6 +52,7 @@ import org.apache.cassandra.spark.data.partitioner.TokenPartitioner;
 import org.apache.cassandra.spark.reader.EmptyStreamScanner;
 import org.apache.cassandra.spark.reader.StreamScanner;
 import org.apache.cassandra.spark.sparksql.filters.PartitionKeyFilter;
+import org.apache.cassandra.spark.sparksql.filters.SSTableTimeRangeFilter;
 import org.apache.cassandra.spark.utils.test.TestSchema;
 import org.apache.spark.TaskContext;
 
@@ -233,6 +234,16 @@ public class PartitionedDataLayerTests extends VersionRunner
             .isInstanceOf(IllegalArgumentException.class);
     }
 
+    @Test
+    public void testReplicationFactorEachQuorum()
+    {
+        assertThatThrownBy(() -> PartitionedDataLayer
+                                 .validateReplicationFactor(EACH_QUORUM,
+                                                            TestUtils.networkTopologyStrategy(ImmutableMap.of("PV", 3, "MR", 3)),
+                                                            "MR"))
+        .isInstanceOf(IllegalArgumentException.class);
+    }
+
     @ParameterizedTest
     @MethodSource("org.apache.cassandra.spark.data.VersionRunner#bridges")
     public void testSSTableSupplier(CassandraBridge bridge)
@@ -303,7 +314,8 @@ public class PartitionedDataLayerTests extends VersionRunner
 
         // Filter does not fall in spark token range
         StreamScanner scanner = dataLayer.openCompactionScanner(partitionId,
-                                                                Collections.singletonList(filterOutsideRange));
+                                                                Collections.singletonList(filterOutsideRange),
+                                                                SSTableTimeRangeFilter.ALL);
         assertThat(scanner).isInstanceOf(EmptyStreamScanner.class);
     }
 
