@@ -61,6 +61,7 @@ import org.apache.cassandra.spark.sparksql.filters.PartitionKeyFilter;
 import org.apache.cassandra.spark.sparksql.filters.PruneColumnFilter;
 import org.apache.cassandra.spark.sparksql.filters.SparkRangeFilter;
 import org.apache.cassandra.analytics.stats.Stats;
+import org.apache.cassandra.spark.sparksql.filters.SSTableTimeRangeFilter;
 import org.apache.cassandra.spark.utils.TimeProvider;
 import org.apache.cassandra.util.CompressionUtil;
 import org.jetbrains.annotations.NotNull;
@@ -88,6 +89,7 @@ public abstract class CassandraBridge
                                                                 @NotNull SSTablesSupplier ssTables,
                                                                 @Nullable SparkRangeFilter sparkRangeFilter,
                                                                 @NotNull Collection<PartitionKeyFilter> partitionKeyFilters,
+                                                                @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                                                                 @Nullable PruneColumnFilter columnFilter,
                                                                 @NotNull TimeProvider timeProvider,
                                                                 boolean readIndexOffset,
@@ -572,33 +574,37 @@ public abstract class CassandraBridge
     /**
      * Convenience method around `readPartitionKeys` to accept partition keys as string values and encode with the correct types.
      *
-     * @param partitioner Cassandra partitioner
-     * @param keyspace    keyspace name
-     * @param createStmt  create table CQL statement
-     * @param ssTables    set of SSTables to read
-     * @param rowConsumer Consumer interface to consume rows as they are read to avoid buffering all rows in memory for consumption.
+     * @param partitioner               Cassandra partitioner
+     * @param keyspace                  keyspace name
+     * @param createStmt                create table CQL statement
+     * @param ssTables                  set of SSTables to read
+     * @param sstableTimeRangeFilter    SSTable time range filter for filtering out SSTable based on min and max timestamp
+     * @param rowConsumer               Consumer interface to consume rows as they are read to avoid buffering all rows in memory for consumption.
      * @throws IOException
      */
     public void readStringPartitionKeys(@NotNull Partitioner partitioner,
                                         @NotNull String keyspace,
                                         @NotNull String createStmt,
                                         @NotNull Set<SSTable> ssTables,
+                                        @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                                         @NotNull Consumer<Map<String, Object>> rowConsumer) throws IOException
     {
-        readStringPartitionKeys(partitioner, keyspace, createStmt, ssTables, null, null, null, rowConsumer);
+        readStringPartitionKeys(partitioner, keyspace, createStmt, ssTables, null, null, null, sstableTimeRangeFilter, rowConsumer);
     }
 
     /**
      * Convenience method around `readPartitionKeys` to accept partition keys as string values and encode with the correct types.
      *
-     * @param partitioner       Cassandra partitioner
-     * @param keyspace          keyspace name
-     * @param createStmt        create table CQL statement
-     * @param ssTables          set of SSTables to read
-     * @param tokenRange        optional token range to limit the bulk read to a restricted token range.
-     * @param partitionKeys     list of partition keys, if more than one partition keys they must be correctly ordered in the inner list.
-     * @param pruneColumnFilter optional filter to select a subset of columns, this can offer performance improvement if skipping over large blobs or columns.
-     * @param rowConsumer       Consumer interface to consume rows as they are read to avoid buffering all rows in memory for consumption.
+     * @param partitioner               Cassandra partitioner
+     * @param keyspace                  keyspace name
+     * @param createStmt                create table CQL statement
+     * @param ssTables                  set of SSTables to read
+     * @param tokenRange                optional token range to limit the bulk read to a restricted token range.
+     * @param partitionKeys             list of partition keys, if more than one partition keys they must be correctly ordered in the inner list.
+     * @param pruneColumnFilter         optional filter to select a subset of columns, this can offer performance
+     *                                  improvement if skipping over large blobs or columns.
+     * @param sstableTimeRangeFilter    SSTable time range filter, filters out SSTables not overlapping given time ranges
+     * @param rowConsumer               Consumer interface to consume rows as they are read to avoid buffering all rows in memory for consumption.
      * @throws IOException
      */
     public void readStringPartitionKeys(@NotNull Partitioner partitioner,
@@ -608,6 +614,7 @@ public abstract class CassandraBridge
                                         @Nullable TokenRange tokenRange,
                                         @Nullable List<List<String>> partitionKeys,
                                         @Nullable String[] pruneColumnFilter,
+                                        @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                                         @NotNull Consumer<Map<String, Object>> rowConsumer) throws IOException
     {
         readPartitionKeys(partitioner,
@@ -617,6 +624,7 @@ public abstract class CassandraBridge
                           tokenRange,
                           partitionKeys == null ? null : encodePartitionKeys(partitioner, keyspace, createStmt, partitionKeys),
                           pruneColumnFilter,
+                          sstableTimeRangeFilter,
                           rowConsumer);
     }
 
@@ -624,9 +632,10 @@ public abstract class CassandraBridge
                                   @NotNull String keyspace,
                                   @NotNull String createStmt,
                                   @NotNull Set<SSTable> ssTables,
+                                  @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                                   @NotNull Consumer<Map<String, Object>> rowConsumer) throws IOException
     {
-        readPartitionKeys(partitioner, keyspace, createStmt, ssTables, null, null, null, rowConsumer);
+        readPartitionKeys(partitioner, keyspace, createStmt, ssTables, null, null, null, sstableTimeRangeFilter, rowConsumer);
     }
 
     public void readPartitionKeys(@NotNull Partitioner partitioner,
@@ -636,9 +645,11 @@ public abstract class CassandraBridge
                                   @Nullable TokenRange tokenRange,
                                   @Nullable List<ByteBuffer> partitionKeys,
                                   @Nullable String[] pruneColumnFilter,
+                                  @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                                   @NotNull Consumer<Map<String, Object>> rowConsumer) throws IOException
     {
-        readPartitionKeys(partitioner, keyspace, createStmt, new BasicSupplier(ssTables), tokenRange, partitionKeys, pruneColumnFilter, rowConsumer);
+        readPartitionKeys(partitioner, keyspace, createStmt, new BasicSupplier(ssTables), tokenRange, partitionKeys,
+                          pruneColumnFilter, sstableTimeRangeFilter, rowConsumer);
     }
 
     public abstract void readPartitionKeys(@NotNull Partitioner partitioner,
@@ -648,6 +659,7 @@ public abstract class CassandraBridge
                                            @Nullable TokenRange tokenRange,
                                            @Nullable List<ByteBuffer> partitionKeys,
                                            @Nullable String[] pruneColumnFilter,
+                                           @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                                            @NotNull Consumer<Map<String, Object>> rowConsumer) throws IOException;
 
     // Kryo/Java (De-)Serialization
