@@ -83,6 +83,7 @@ import org.apache.cassandra.spark.sparksql.filters.PartitionKeyFilter;
 import org.apache.cassandra.spark.sparksql.filters.PruneColumnFilter;
 import org.apache.cassandra.spark.sparksql.filters.SparkRangeFilter;
 import org.apache.cassandra.analytics.stats.Stats;
+import org.apache.cassandra.spark.sparksql.filters.SSTableTimeRangeFilter;
 import org.apache.cassandra.spark.utils.ByteBufferUtils;
 import org.apache.cassandra.spark.utils.Pair;
 import org.apache.cassandra.spark.utils.ThrowableUtils;
@@ -118,6 +119,8 @@ public class SSTableReader implements SparkSSTableReader, Scannable
     @NotNull
     private final List<PartitionKeyFilter> partitionKeyFilters;
     @NotNull
+    private final SSTableTimeRangeFilter sstableTimeRangeFilter;
+    @NotNull
     private final Stats stats;
     @Nullable
     private Long startOffset = null;
@@ -143,6 +146,8 @@ public class SSTableReader implements SparkSSTableReader, Scannable
         SparkRangeFilter sparkRangeFilter = null;
         @NotNull
         final List<PartitionKeyFilter> partitionKeyFilters = new ArrayList<>();
+        @NotNull
+        SSTableTimeRangeFilter sstableTimeRangeFilter = SSTableTimeRangeFilter.ALL;
 
         Builder(@NotNull TableMetadata metadata, @NotNull SSTable ssTable)
         {
@@ -171,6 +176,15 @@ public class SSTableReader implements SparkSSTableReader, Scannable
             return this;
         }
 
+        public Builder withTimeRangeFilter(@Nullable SSTableTimeRangeFilter sstableTimeRangeFilter)
+        {
+            if (sstableTimeRangeFilter != null)
+            {
+                this.sstableTimeRangeFilter = sstableTimeRangeFilter;
+            }
+            return this;
+        }
+
         public Builder withColumnFilter(@Nullable PruneColumnFilter columnFilter)
         {
             this.columnFilter = columnFilter;
@@ -213,6 +227,7 @@ public class SSTableReader implements SparkSSTableReader, Scannable
                                      ssTable,
                                      sparkRangeFilter,
                                      partitionKeyFilters,
+                                     sstableTimeRangeFilter,
                                      columnFilter,
                                      readIndexOffset,
                                      stats,
@@ -232,6 +247,7 @@ public class SSTableReader implements SparkSSTableReader, Scannable
                          @NotNull SSTable ssTable,
                          @Nullable SparkRangeFilter sparkRangeFilter,
                          @NotNull List<PartitionKeyFilter> partitionKeyFilters,
+                         @NotNull SSTableTimeRangeFilter sstableTimeRangeFilter,
                          @Nullable PruneColumnFilter columnFilter,
                          boolean readIndexOffset,
                          @NotNull Stats stats,
@@ -304,6 +320,7 @@ public class SSTableReader implements SparkSSTableReader, Scannable
             header = null;
             helper = null;
             this.metadata = null;
+            this.sstableTimeRangeFilter = SSTableTimeRangeFilter.ALL;
             return;
         }
 
@@ -330,6 +347,7 @@ public class SSTableReader implements SparkSSTableReader, Scannable
                 header = null;
                 helper = null;
                 this.metadata = null;
+                this.sstableTimeRangeFilter = SSTableTimeRangeFilter.ALL;
                 return;
             }
         }
@@ -348,6 +366,21 @@ public class SSTableReader implements SparkSSTableReader, Scannable
         }
 
         this.statsMetadata = (StatsMetadata) componentMap.get(MetadataType.STATS);
+        if (!sstableTimeRangeFilter.overlaps(statsMetadata.minTimestamp, statsMetadata.maxTimestamp))
+        {
+            LOGGER.info("Ignoring SSTableReader with minTimestamp={} maxTimestamp={}, does not overlap with filter {}",
+                        this.statsMetadata.minTimestamp, this.statsMetadata.maxTimestamp, sstableTimeRangeFilter);
+            header = null;
+            helper = null;
+            this.metadata = null;
+            this.sstableTimeRangeFilter = SSTableTimeRangeFilter.ALL;
+            return;
+        }
+        else
+        {
+            this.sstableTimeRangeFilter = sstableTimeRangeFilter;
+        }
+
         SerializationHeader.Component headerComp = (SerializationHeader.Component) componentMap.get(MetadataType.HEADER);
         if (headerComp == null)
         {
